.. currentmodule:: sardana.pool.poolmotion

:mod:`~sardana.pool.poolmotion`
=========================================

.. automodule:: sardana.pool.poolmotion

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolMotionItem`
    * :class:`PoolMotion`


PoolMotionItem
-------------------

.. inheritance-diagram:: PoolMotionItem
    :parts: 1
    
.. autoclass:: PoolMotionItem
    :show-inheritance:
    :members:
    :undoc-members:

PoolMotion
-------------------

.. inheritance-diagram:: PoolMotion
    :parts: 1
    
.. autoclass:: PoolMotion
    :show-inheritance:
    :members:
    :undoc-members:
    
.. rubric:: Enumerations

.. autodata:: sardana.pool.poolmotion.MotionState